@@ -46,6 +46,7 @@ myst_enable_extensions = [
     "substitution",
     "replacements",
     "strikethrough",
+    "linkify",
 ]
 
 templates_path = ["_templates"]
@@ -108,6 +109,11 @@ issue_url_tpl = f'{about["__github__"]}/issues/{{issue_id}}'
 # sphinx.ext.autodoc
 autoclass_content = "both"
 autodoc_member_order = "bysource"
+# Automatically extract typehints when specified and place them in
+# descriptions of the relevant function/method.
+autodoc_typehints = "description"
+# Don't show class signature with the class' name.
+autodoc_class_signature = "separated"
 toc_object_entries_show_parents = "hide"
 
 # sphinx-copybutton
@@ -192,15 +198,14 @@ def linkcode_resolve(domain: str, info: t.Dict[str, str]) -> t.Union[None, str]:
             fn,
             linespec,
         )
-    else:
-        return "{}/blob/v{}/{}/{}/{}{}".format(
-            about["__github__"],
-            about["__version__"],
-            "src",
-            about["__package_name__"],
-            fn,
-            linespec,
-        )
+    return "{}/blob/v{}/{}/{}/{}{}".format(
+        about["__github__"],
+        about["__version__"],
+        "src",
+        about["__package_name__"],
+        fn,
+        linespec,
+    )
 
 
 def remove_tabs_js(app: "Sphinx", exc: Exception) -> None:
